[−][src]Struct rocksdb::ReadOptions
Methods
impl ReadOptions[src]
pub unsafe fn set_iterate_upper_bound<K: AsRef<[u8]>>(&mut self, key: K)[src]
Set the upper bound for an iterator. The upper bound itself is not included on the iteration result.
Safety
This function will store a clone of key and will give a raw pointer of it to the
underlying C++ API, therefore, when given to any other DB method you must ensure
that this ReadOptions value does not leave the scope too early (e.g. DB::iterator_cf_opt).
pub fn set_prefix_same_as_start(&mut self, v: bool)[src]
pub fn set_total_order_seek(&mut self, v: bool)[src]
pub fn set_verify_checksums(&mut self, v: bool)[src]
If true, all data read from underlying storage will be verified against corresponding checksums.
Default: true
pub fn set_readahead_size(&mut self, v: usize)[src]
If non-zero, an iterator will create a new table reader which performs reads of the given size. Using a large size (> 2MB) can improve the performance of forward iteration on spinning disks. Default: 0
use rocksdb::{ReadOptions}; let mut opts = ReadOptions::default(); opts.set_readahead_size(4_194_304); // 4mb
pub fn set_tailing(&mut self, v: bool)[src]
If true, create a tailing iterator. Note that tailing iterators only support moving in the forward direction. Iterating in reverse or seek_to_last are not supported.